@@ -29,7 +29,6 @@ pub struct Conflicts<StorageT> {
 impl<StorageT: 'static + Hash + PrimInt + Unsigned> Conflicts<StorageT>
 where
     usize: AsPrimitive<StorageT>,
-    u32: AsPrimitive<StorageT>,
 {
     /// Return an iterator over all reduce/reduce conflicts.
     pub fn rr_conflicts(&self) -> impl Iterator<Item = &(PIdx<StorageT>, PIdx<StorageT>, StIdx)> {
@@ -158,17 +157,16 @@ const ERROR: usize = 0;
 impl<StorageT: 'static + Hash + PrimInt + Unsigned> StateTable<StorageT>
 where
     usize: AsPrimitive<StorageT>,
-    u32: AsPrimitive<StorageT>,
 {
     pub fn new(
         grm: &YaccGrammar<StorageT>,
         sg: &StateGraph<StorageT>,
     ) -> Result<Self, StateTableError<StorageT>> {
         let mut state_actions = Vob::from_elem(
+            false,
             usize::from(sg.all_states_len())
                 .checked_mul(usize::from(grm.tokens_len()))
                 .unwrap(),
-            false,
         );
         let maxa = usize::from(grm.tokens_len()) * usize::from(sg.all_states_len());
         let maxg = usize::from(grm.rules_len()) * usize::from(sg.all_states_len());
@@ -290,18 +288,18 @@ where
 
         let mut nt_depth = HashMap::new();
         let mut core_reduces = Vob::from_elem(
+            false,
             usize::from(sg.all_states_len())
                 .checked_mul(usize::from(grm.prods_len()))
                 .unwrap(),
-            false,
         );
         let mut state_shifts = Vob::from_elem(
+            false,
             usize::from(sg.all_states_len())
                 .checked_mul(usize::from(grm.tokens_len()))
                 .unwrap(),
-            false,
         );
-        let mut reduce_states = Vob::from_elem(usize::from(sg.all_states_len()), false);
+        let mut reduce_states = Vob::from_elem(false, usize::from(sg.all_states_len()));
         for stidx in sg.iter_stidxs() {
             nt_depth.clear();
             let mut only_reduces = true;
@@ -538,7 +536,6 @@ fn resolve_shift_reduce<StorageT: 'static + Hash + PrimInt + Unsigned>(
     conflict_stidx: StIdx, // State in which the conflict occured
 ) where
     usize: AsPrimitive<StorageT>,
-    u32: AsPrimitive<StorageT>,
 {
     let tidx_prec = grm.token_precedence(tidx);
     let pidx_prec = grm.prod_precedence(pidx);
